@@ -7,10 +7,10 @@
  *		HAVE_* and WITH_* defines are substituted at
  *		build time by make with values from autoconf.h.
  *
- * Version:	$Id: bb74e060b9e4c54c94947d7bc9666ea95ff90370 $
+ * Version:	$Id: 5698797b0e0831c7d6b27ad6db46f815c6c3f23d $
  *
  */
-RCSIDH(missing_h, "$Id: bb74e060b9e4c54c94947d7bc9666ea95ff90370 $")
+RCSIDH(missing_h, "$Id: 5698797b0e0831c7d6b27ad6db46f815c6c3f23d $")
 
 #if 1
 #  include <stdint.h>
@@ -516,6 +516,10 @@ size_t SSL_SESSION_get_master_key(const SSL_SESSION *s,
 #define O_DIRECTORY 0
 #endif
 
+#ifndef O_NOFOLLOW
+#define O_NOFOLLOW 0
+#endif
+
 /*
  *	Not really missing, but may be submitted as patches
  *	to the talloc project at some point in the future.
